@@ -1,7 +1,7 @@
 # -*- mode: Perl -*-
 package MRTG_lib;
 ###################################################################
-# MRTG 2.17.1  Support library MRTG_lib.pm
+# MRTG 2.17.7  Support library MRTG_lib.pm
 ###################################################################
 # Created by Tobias Oetiker <tobi@oetiker.ch>
 #            and Dave Rand <dlr@bungi.com>
@@ -156,6 +156,10 @@ $VERSION = 2.100016;
 #       [sub{(($_[0] =~ /^unix:(\S+)/)and(-w $1))}, sub{"Currently, only UNIX domain sockets are supported for RRDCached, and must exist and be writeable."}],
        [sub{1},sub{"Internal Error"}],
 
+       # Get graphite server name/ip and port
+       'sendtographite' =>
+       [sub{$_[0] =~ /^.*,\d+$/}, sub{"Invalid Graphite Destination '$_[0]'"}],
+
        # Per Router CFG
        'target[]' => 
        [sub{1}, sub{"Internal Error"}], #will test this later
@@ -684,7 +688,7 @@ sub quickcheck ($$$$$$) {
         }
     }
     die "ERROR: CFG Error Unknown Option \"$first\" in file $file on line $line or above.\n".
-      "           Check doc/mrtg-reference.txt for Help\n\n";
+      "           Check /usr/share/doc/mrtg/mrtg-reference.txt.gz for Help\n\n";
 }
 
 # complex config checks
@@ -782,6 +786,7 @@ sub cfgcheck ($$$$;$) {
     debug('dir', "imagehtml = $$cfg{imagehtml}");
 
     $SNMP_util::CacheFile = "$$cfg{'logdir'}oid-mib-cache.txt";
+    $Net_SNMP_util::CacheFile = "$$cfg{'logdir'}oid-mib-cache.txt";
 
     if (defined $$cfg{loadmibs}) {
         my($mibFile);
@@ -872,6 +877,23 @@ sub cfgcheck ($$$$;$) {
 
     my $thresh_error;
 
+    # sendtographite directive parsing
+    # sanity check for <ip>,<port> or <dnsname>,<port>
+    if ($cfg->{sendtographite}){
+      my @a = split ",",$cfg->{sendtographite};
+
+      # is this an IP address?
+      unless($a[0] =~ /^(?:[0-9]{1,3}\.){3}[0-9]{1,3}$/) { 
+        # maybe we were passed a DNS name?
+        unless(gethostbyname($a[0])) { die "ERROR: cannot find graphite server name $a[0] in DNS\n"; }
+      }
+      
+      # if we got this far, now check the port number range
+      unless($a[1] > 0 and $a[1] < 65536) {
+        die "ERROR: invalid port number $a[1] in sendtographite directive\n";
+      }
+    }
+
     foreach $rou (@$routers) {
         # and now for the testing
 	if (defined $rcfg->{threshmailaddress}{$rou}){
@@ -1112,8 +1134,7 @@ sub cfgcheck ($$$$;$) {
         }
         if (defined $$rcfg{'options'}{'pngdate'}{$rou}) {
             $$rcfg{'timestrpos'}{$rou} = 'RU';
-            $$rcfg{'timestrfmt'}{$rou} = "%Y-%m-%d %H:%M %Z";
-
+            $$rcfg{'timestrfmt'}{$rou} = $$rcfg{'timezone'}{$rou} ? "%Y-%m-%d %H:%M %Z" : "%Y-%m-%d %H:%M";
             delete $$rcfg{'options'}{'pntdate'}{$rou}
         }
         if (! defined $$rcfg{'timestrpos'}{$rou}) {
